[ Module Hierarchy | Class Hierarchy ]

# Class Hierarchy

- object: The most base type
  - unreachable.Geod
    - pyproj.Geod: performs forward and inverse geodetic, or Great Circle, computations.
  - unreachable.Proj
    - pyproj.Proj: performs cartographic transformations (converts from longitude,latitude to native map projection x,y coordinates and vice versa) using proj (http://trac.osgeo.org/proj/).